@@ -842,7 +842,12 @@ def registration_number(
 
     if field_path[:2] == "n_":
         unit = unyt.dimensionless
-        switch = {"bh": "Black Hole", "gas": "Gas", "star": "Star", "interloper": "Interloper"}
+        switch = {
+            "bh": "Black Hole",
+            "gas": "Gas",
+            "star": "Star",
+            "interloper": "Interloper",
+        }
         snake_case = field_path[2:]
         full_name = f"Number of {switch.get(snake_case, 'Unknown')} Particles"
 
@@ -857,6 +862,273 @@ def registration_number(
     return unit, full_name, snake_case
 
 
+def registration_gas_H_and_He_masses(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the masses in Hydrogen & Helium within apertures
+    """
+
+    unit = unit_system.mass
+
+    # Capture aperture size
+    match_string = "Aperture_([a-zA-Z]*)_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        long_species = match.group(1)
+        aperture_size = match.group(2)
+
+        try:
+            short_species = {"HeliumMasses": "He", "HydrogenMasses": "H"}[long_species]
+            long_name_species = {
+                "HeliumMasses": "Helium",
+                "HydrogenMasses": "Hydrogen",
+            }[long_species]
+            math_name = {"HeliumMasses": "M_{\\rm He}", "HydrogenMasses": "M_{\\rm H}"}[
+                long_species
+            ]
+        except KeyError:
+            raise RegistrationDoesNotMatchError
+
+        full_name = f"{long_name_species} Gas Mass {math_name} ({aperture_size} kpc)"
+        snake_case = f"{short_species}_mass_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
+def registration_gas_diffuse_element_masses(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the masses in Hydrogen & Helium within apertures
+    """
+
+    unit = unit_system.mass
+
+    # Capture aperture size
+    match_string = "Aperture_Diffuse([a-zA-Z]*)MassesFrom(Table|Model)_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        element = match.group(1)
+        table_model = match.group(2)
+        aperture_size = match.group(3)
+        try:
+            long_name_element = (
+                f"Diffuse {element} from depletion {table_model.lower()}"
+            )
+            element_symbol = {
+                "Carbon": "C",
+                "Oxygen": "O",
+                "Magnesium": "Mg",
+                "Silicon": "Si",
+                "Iron": "Fe",
+            }[element]
+            math_name = (
+                f"M^{{\\rm {table_model.lower()}}}_{{\\rm {element_symbol}, diffuse}}"
+            )
+        except KeyError:
+            raise RegistrationDoesNotMatchError
+
+        full_name = (
+            f"{element} ({table_model}) Gas Mass {element_symbol} ({aperture_size} kpc)"
+        )
+        snake_case = f"{element.lower()}_mass_{table_model.lower()}_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
+def registration_dust_masses_from_table(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the dust mass fraction properties.
+    """
+
+    if not field_path[:28] == "Aperture_DustMassesFromTable":
+        raise RegistrationDoesNotMatchError
+
+    unit = unit_system.mass
+
+    match_string = "Aperture_DustMassesFromTable_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+    match = regex.match(field_path)
+
+    if match:
+        aperture_size = match.group(1)
+        full_name = f"Total Dust Mass from Tables ({aperture_size} kpc)"
+        snake_case = f"dust_mass_table_{aperture_size}_kpc"
+    else:
+        raise RegistrationDoesNotMatchError
+
+    return unit, full_name, snake_case
+
+
+def registration_gas_hydrogen_species_masses(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the masses in hydrogen species within apertures.
+    """
+
+    unit = unit_system.mass
+
+    # Capture aperture size
+    match_string = "Aperture_([a-zA-Z]*)_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        long_species = match.group(1)
+        aperture_size = match.group(2)
+
+        try:
+            short_species = {
+                "AtomicHydrogenMasses": "HI",
+                "IonisedHydrogenMasses": "HII",
+                "MolecularHydrogenMasses": "H2",
+            }[long_species]
+            full_name_species = {
+                "AtomicHydrogenMasses": "HI",
+                "IonisedHydrogenMasses": "HII",
+                "MolecularHydrogenMasses": "H$_2$",
+            }[long_species]
+            math_name_species = {
+                "AtomicHydrogenMasses": "$M_{\\rm HI}$",
+                "IonisedHydrogenMasses": "$M_{\\rm HII}$",
+                "MolecularHydrogenMasses": "$M_{\\rm H_2}$",
+            }[long_species]
+
+        except KeyError:
+            raise RegistrationDoesNotMatchError
+
+        full_name = (
+            f"{full_name_species} Gas Mass {math_name_species} ({aperture_size} kpc)"
+        )
+        snake_case = f"{short_species}_mass_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
+def registration_gas_element_ratios_times_masses(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the Fe/H times mass and O/H times mass within apertures
+    """
+
+    unit = unit_system.mass
+
+    # Capture aperture size
+    match_string = "Aperture_([a-zA-Z]*)_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        long_species = match.group(1)
+        aperture_size = match.group(2)
+
+        try:
+            short_species = {
+                "OxygenOverHydrogenMasses": "O_over_H",
+                "IronOverHydrogenMasses": "Fe_over_H",
+            }[long_species]
+            element_name = {
+                "OxygenOverHydrogenMasses": "Oxygen",
+                "IronOverHydrogenMasses": "Iron",
+            }[long_species]
+            fraction_name = {
+                "OxygenOverHydrogenMasses": "(O/H)",
+                "IronOverHydrogenMasses": "(Fe/H)",
+            }[long_species]
+        except KeyError:
+            raise RegistrationDoesNotMatchError
+
+        full_name = f"{element_name} Abundance Weighted Gas Mass {fraction_name}$\times M_{{\\rm gas}}$ ({aperture_size} kpc)"
+        snake_case = f"{short_species}_times_gas_mass_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
+def registration_dust_masses(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the masses in dust within apertures
+    """
+
+    unit = unit_system.mass
+
+    # Capture aperture size
+    match_string = "Aperture_([a-zA-Z]*)_aperture_total_gas_([0-9]*)_kpc"
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        long_species = match.group(1)
+        aperture_size = match.group(2)
+
+        try:
+            short_species = {
+                "GraphiteMasses": "graphite",
+                "SilicatesMasses": "silicates",
+            }[long_species]
+        except KeyError:
+            raise RegistrationDoesNotMatchError
+
+        full_name = f"{short_species} Dust Mass ({aperture_size} kpc)"
+        snake_case = f"{short_species}_mass_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
+def registration_stellar_luminosities(
+    field_path: str, unit_system: VelociraptorUnits
+) -> (unyt.Unit, str, str):
+    """
+    Registers the luminosities within apertures
+    """
+
+    unit = unyt.dimensionless
+
+    # Capture aperture size
+    match_string = (
+        "Aperture_Luminosities_([a-zA-Z])_index_0_aperture_total_star_([0-9]*)_kpc"
+    )
+    regex = cached_regex(match_string)
+
+    match = regex.match(field_path)
+
+    if match:
+        band = match.group(1)
+        aperture_size = match.group(2)
+
+        full_name = f"{band}-Band Luminosity ({aperture_size} kpc)"
+        snake_case = f"{band}_luminosity_{aperture_size}_kpc"
+
+        return unit, full_name, snake_case
+    else:
+        raise RegistrationDoesNotMatchError
+
+
 def registration_hydrogen_phase_fractions(
     field_path: str, unit_system: VelociraptorUnits
 ) -> (unyt.Unit, str, str):
@@ -1124,6 +1396,13 @@ global_registration_functions = {
         "stellar_birth_densities",
         "snii_thermal_feedback_densities",
         "species_fractions",
+        "gas_hydrogen_species_masses",
+        "gas_H_and_He_masses",
+        "gas_diffuse_element_masses",
+        "dust_masses_from_table",
+        "dust_masses",
+        "gas_element_ratios_times_masses",
+        "stellar_luminosities",
         "fail_all",
     ]
 }
